@@ -1,34 +1,33 @@
 # !/usr/bin/env python3
-# encoding: utf-8
+# -*- coding: utf-8 -*-
 from os import getpid
 from asyncio import get_event_loop, sleep
 from time import sleep as t_sleep
 from ssl import SSLContext
 from requests import Session
-from requests.adapters import HTTPAdapter
-from urllib3.util.retry import Retry
-from typing import Any, Callable, Union
+from requests.adapters import HTTPAdapter, Retry
+from typing import Any, Callable, Union, Optional
+from . import _api_model
+from .version import __version__
 from .logger import Logger
 from .model import Model
-from ._api_model import ReplyModel
 from .qg_bot_ws import BotWs
-from ._utils import objectize, exception_handler
+from ._utils import exception_processor
 from .api import API
 
-reply_model = ReplyModel()
-retry = Retry(total=4, connect=3, backoff_factor=0.5)
+retry = Retry(total=4, connect=2, read=2)
 adapter = HTTPAdapter(max_retries=retry)
-version = '2.3.1'
 pid = getpid()
-print(f'本次程序进程ID：{pid} | SDK版本：{version} | 即将开始运行机器人……')
+print(f'本次程序进程ID：{pid} | SDK版本：{__version__} | 即将开始运行机器人……')
 t_sleep(0.5)
 
 
 class BOT:
 
-    def __init__(self, bot_id: str, bot_token: str, bot_secret: str = None, is_private: bool = False,
+    def __init__(self, bot_id: str, bot_token: str, bot_secret: Optional[str] = None, is_private: bool = False,
                  is_sandbox: bool = False, no_permission_warning: bool = True, is_async: bool = False,
-                 is_retry: bool = True, is_log_error: bool = True, shard_no: int = 0, total_shard: int = 1):
+                 is_retry: bool = True, is_log_error: bool = True, shard_no: int = 0, total_shard: int = 1,
+                 max_workers: Optional[int] = None):
         """
         机器人主体，输入BotAppID和密钥，并绑定函数后即可快速使用
 
@@ -43,20 +42,18 @@ class BOT:
         :param is_log_error: 使用api时，如返回的结果为不成功，可自动log输出报错信息，默认开启
         :param shard_no: 当前分片数，如不熟悉相关配置请不要轻易改动此项，默认0
         :param total_shard: 最大分片数，如不熟悉相关配置请不要轻易改动此项，默认1
+        :param max_workers: 在同步模式下，允许同时运行的最大线程数
         """
         self.logger = Logger(bot_id)
         self.bot_id = bot_id
         self.bot_token = bot_token
         self.bot_secret = bot_secret
         self.is_private = is_private
-        if is_sandbox:
-            self.bot_url = r'https://sandbox.api.sgroup.qq.com'
-        else:
-            self.bot_url = r'https://api.sgroup.qq.com'
+        self.bot_url = r'https://sandbox.api.sgroup.qq.com' if is_sandbox else r'https://api.sgroup.qq.com'
         if not self.bot_id or not self.bot_token:
             raise type('IdTokenMissing', (Exception,), {})(
                 '你还没有输入 bot_id 和 bot_token，无法连接使用机器人\n如尚未有相关票据，'
-                '请参阅 https://thoughts.teambition.com/share/627533408adeb10041b935b1#title=快速入门 了解相关详情')
+                '请参阅 https://qg-botsdk.readthedocs.io/zh_CN/latest/quick_start 了解相关详情')
         self.intents = 0
         self.shard_no = shard_no
         self.total_shard = total_shard
@@ -75,7 +72,7 @@ class BOT:
         self.__on_start_function = None
         self.is_filter_self = True
         self.check_interval = 10
-        self.running = False
+        self.__running = False
         self.bot_headers = {'Authorization': f"Bot {self.bot_id}.{self.bot_token}"}
         self.__ssl = SSLContext()
         self.__session = Session()
@@ -84,31 +81,43 @@ class BOT:
         self.__session.mount('http://', adapter)
         self.__session.mount('https://', adapter)
         self.__bot_class = None
-        self.__loop = get_event_loop()
+        self._loop = get_event_loop()
         self.msg_treat = True
         self.dm_treat = False
         self.no_permission_warning = no_permission_warning
+        self.max_workers = max_workers
         self.is_async = is_async
         if not is_async:
-            self.api = API(self.bot_url, bot_id, bot_secret, self.__session, self.logger, self.check_warning,
-                           self.__get_bot_id, is_retry, is_log_error)
+            self.api: API = API(self.bot_url, bot_id, bot_secret, self.__session, self.logger, self._check_warning,
+                                is_retry, is_log_error)
         else:
             from .async_api import AsyncAPI
-            self.api: Union[API, AsyncAPI] = AsyncAPI(self.bot_url, bot_id, bot_secret, self.__ssl, self.bot_headers,
-                                                      self.logger, self.__loop, self.check_warning, self.__get_bot_id,
+            self.api: Union[AsyncAPI, API] = AsyncAPI(self.bot_url, bot_id, bot_secret, self.__ssl, self.bot_headers,
+                                                      self.logger, self._loop, self._check_warning,
                                                       is_retry, is_log_error)
 
+    def __repr__(self):
+        return f"<qg_botsdk.BOT object [id: {self.bot_id}, token: {self.bot_token}]>"
+
+    @property
+    def robot(self) -> _api_model.robot():
+        return self.__bot_class.robot
+
+    @property
+    def running(self):
+        return self.__running
+
+    @exception_processor
+    def __time_event_run(self):
+        if self.is_async:
+            self._loop.create_task(self.__repeat_function())
+        else:
+            self.__repeat_function()
+
     async def __time_event_check(self):
-        while self.running:
-            try:
-                if self.is_async:
-                    await self.__repeat_function()
-                else:
-                    self.__repeat_function()
-            except Exception as error:
-                self.logger.error(error)
-                self.logger.debug(exception_handler(error))
+        while self.__running:
             await sleep(self.check_interval)
+            self.__time_event_run()
 
     def bind_msg(self, on_msg_function: Callable[[Model.MESSAGE], Any], treated_data: bool = True,
                  all_msg: bool = None):
@@ -168,7 +177,7 @@ class BOT:
         :param on_guild_event_function: 类型为function，该函数应包含一个参数以接收Object消息数据进行处理
         """
         self.__on_guild_event_function = on_guild_event_function
-        self.intents = self.intents | 1 << 0
+        self.intents = self.intents | 1
         self.logger.info('频道事件订阅成功')
 
     def bind_channel_event(self, on_channel_event_function: Callable[[Model.CHANNELS], Any]):
@@ -178,7 +187,7 @@ class BOT:
         :param on_channel_event_function: 类型为function，该函数应包含一个参数以接收Object消息数据进行处理
         """
         self.__on_channel_event_function = on_channel_event_function
-        self.intents = self.intents | 1 << 0
+        self.intents = self.intents | 1
         self.logger.info('子频道事件订阅成功')
 
     def bind_guild_member(self, on_guild_member_function: Callable[[Model.GUILD_MEMBERS], Any]):
@@ -201,9 +210,9 @@ class BOT:
         self.intents = self.intents | 1 << 10
         self.logger.info('表情表态事件订阅成功')
 
-    def bind_interaction(self, on_interaction_function: Callable[[Any], Any]):
+    def bind_interaction(self, on_interaction_function: Callable[[Model.INTERACTION], Any]):
         """
-        用作绑定接收互动事件的函数，当前未有录入数据结构
+        用作绑定接收互动事件的函数
 
         :param on_interaction_function: 类型为function，该函数应包含一个参数以接收Object消息数据进行处理
         """
@@ -249,7 +258,7 @@ class BOT:
         if self.no_permission_warning:
             self.logger.warning('请注意，一般机器人并不能注册音频事件（需先进行申请），请检查自身是否拥有相关权限（如已申请可忽略此消息）')
 
-    def register_repeat_event(self, time_function: Callable[[], Any], check_interval: float or int = 10):
+    def register_repeat_event(self, time_function: Callable[[], Any], check_interval: Union[float, int] = 10):
         """
         用作注册重复事件的函数，注册并开始机器人后，会根据间隔时间不断调用注册的函数
 
@@ -269,45 +278,34 @@ class BOT:
         self.__on_start_function = on_start_function
         self.logger.info('初始事件注册成功')
 
-    def check_warning(self, name: str):
+    def _check_warning(self, name: str):
         if not self.is_private and self.no_permission_warning:
             self.logger.warning(f'请注意，一般公域机器人并不能使用{name}API，请检查自身是否拥有相关权限')
 
-    def __get_bot_id(self):
-        """
-        获取机器人在频道场景的用户ID
-
-        :return: 返回的.data中为机器人用户ID，如未注册则返回None
-        """
-        try:
-            return objectize({'data': self.__bot_class.bot_qid, 'result': True})
-        except IndexError:
-            return objectize({'data': None, 'result': False})
-
     def start(self):
         """
         开始运行机器人的函数，在唤起此函数后的代码将不能运行，如需运行后续代码，请以多进程方式唤起此函数，以下是一个简单的唤起流程：
 
-        >>> from qg_botsdk.qg_bot import BOT
+        >>> from qg_botsdk import BOT
         >>> bot = BOT(bot_id='xxx', bot_token='xxx')
         >>> bot.start()
 
         .. seealso::
             更多教程和相关资讯可参阅：
-            https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b52
+            https://qg-botsdk.readthedocs.io/zh_CN/latest/index.html
         """
         try:
-            if not self.running and not self.__bot_class:
-                self.running = True
+            if not self.__running and not self.__bot_class:
+                self.__running = True
                 gateway = self.__session.get(self.bot_url + '/gateway/bot').json()
-                if 'url' not in gateway.keys():
+                url = gateway.get('url')
+                if not url:
                     raise type('IdTokenError', (Exception,), {})(
                         '你输入的 bot_id 和/或 bot_token 错误，无法连接使用机器人\n如尚未有相关票据，'
-                        '请参阅 https://thoughts.teambition.com/share/627533408adeb10041b935b1#title=快速入门 了解相关详情')
-                url = gateway["url"]
+                        '请参阅 https://qg-botsdk.readthedocs.io/zh_CN/latest/quick_start 了解相关详情')
                 self.logger.debug('[机器人ws地址] ' + url)
                 if self.__repeat_function is not None:
-                    self.__loop.create_task(self.__time_event_check())
+                    self._loop.create_task(self.__time_event_check())
                 self.__bot_class = BotWs(self.__session, self.__ssl, self.logger, self.total_shard, self.shard_no, url,
                                          self.bot_id, self.bot_token, self.bot_url, self.__on_msg_function,
                                          self.__on_dm_function, self.__on_delete_function, self.is_filter_self,
@@ -315,8 +313,9 @@ class BOT:
                                          self.__on_guild_member_function, self.__on_reaction_function,
                                          self.__on_interaction_function, self.__on_audit_function,
                                          self.__on_forum_function, self.__on_audio_function, self.intents,
-                                         self.msg_treat, self.dm_treat, self.__on_start_function, self.is_async)
-                self.__bot_class.ws_starter()
+                                         self.msg_treat, self.dm_treat, self.__on_start_function, self.is_async,
+                                         self.max_workers if self.max_workers else 10, self.api)
+                self.__bot_class.starter()
             else:
                 self.logger.error('当前机器人已在运行中！')
         except KeyboardInterrupt:
@@ -328,14 +327,14 @@ class BOT:
 
         .. seealso::
             更多教程和相关资讯可参阅：
-            https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b52
+            https://qg-botsdk.readthedocs.io/zh_CN/latest/index.html
         """
-        if self.running:
-            self.running = False
+        if self.__running:
+            self.__running = False
             self.logger.info('WS链接已开始结束进程，请等待另一端完成握手并等待 TCP 连接终止')
             self.__bot_class.running = False
-            timeout = self.__loop.time() + 60
-            while self.__loop.time() > timeout:
+            timeout = self._loop.time() + 60
+            while self._loop.time() > timeout:
                 t_sleep(1)
                 if not self.__bot_class or self.__bot_class.ws.closed:
                     self.logger.info('WS链接已结束')
